=============
steel_toolbox
=============


.. image:: https://img.shields.io/pypi/v/steel_toolbox.svg
        :target: https://pypi.python.org/pypi/steel_toolbox

.. image:: https://img.shields.io/travis/manpan-1/steel_toolbox.svg
        :target: https://travis-ci.org/manpan-1/steel_toolbox

.. image:: https://readthedocs.org/projects/steel-toolbox/badge/?version=latest
        :target: https://steel-toolbox.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/manpan-1/steel_toolbox/shield.svg
     :target: https://pyup.io/repos/github/manpan-1/steel_toolbox/
     :alt: Updates


A collection of classes and tools used on structural steel design.


* Free software: MIT license
* Documentation: https://steel-toolbox.readthedocs.io.


Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

